==> connector-service-1.0.0-20190816.093628-44-sources.jar: com/bizvane/connectorservice/entity/common/MemberOpenCardResponseVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */

public class MemberOpenCardResponseVO extends BaseModel{

    /**
     * 等级Code
     */
    private String levelCode;

    /**
     * 线下卡号
     */
    private String offlineCardNo;

    /**
     * 当前累计可用积分
     */
    private Integer countIntegeral;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 会员性别(1男 0女)
     */
    private Integer gender;

    /**
     * 会员生日 patter = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 会员卡有效期 pattern = "yyyyMMdd"
     */
    private String effectiveTime;

    /**
     * 是否首次注册,  0 是第一次
     */
    private Integer firstandingCheck;

    /**
     * 线下会员Id
     */
    private String erpId;

    public String getLevelCode() {
        return levelCode;
    }

    public void setLevelCode(String levelCode) {
        this.levelCode = levelCode;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public Integer getCountIntegeral() {
        return countIntegeral;
    }

    public void setCountIntegeral(Integer countIntegeral) {
        this.countIntegeral = countIntegeral;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public Integer getFirstandingCheck() {
        return firstandingCheck;
    }

    public void setFirstandingCheck(Integer firstandingCheck) {
        this.firstandingCheck = firstandingCheck;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }
}

==> connector-service-1.0.0-20191024.035944-69-sources.jar: com/bizvane/connectorservice/entity/common/MemberOpenCardResponseVO.java <==
package com.bizvane.connectorservice.entity.common;

import com.bizvane.connectorservice.entity.base.BaseModel;

/**
 * @author liuying
 * @date 2018/8/9
 * @description
 */

public class MemberOpenCardResponseVO extends BaseModel{

    /**
     * 等级Code
     */
    private String levelCode;

    /**
     * 线下卡号
     */
    private String offlineCardNo;

    /**
     * 当前累计可用积分
     */
    private Integer countIntegeral;

    /**
     * 手机号
     */
    private String phone;

    /**
     * 会员姓名
     */
    private String name;

    /**
     * 会员性别(1男 0女)
     */
    private Integer gender;

    /**
     * 会员生日 patter = "yyyyMMdd"
     */
    private String birthday;

    /**
     * 省份
     */
    private String province;

    /**
     * 城市
     */
    private String city;

    /**
     * 区县
     */
    private String county;

    /**
     * 详细地址
     */
    private String address;

    /**
     * 开卡门店编号
     */
    private String openStoreCode;

    /**
     * 开卡导购编号
     */
    private String openGuideCode;

    /**
     * 会员卡有效期 pattern = "yyyyMMdd"
     */
    private String effectiveTime;

    /**
     * 是否首次注册,  0 是第一次
     */
    private Integer firstandingCheck;

    /**
     * 线下会员Id
     */
    private String erpId;



    /** 2019-09-19新增
     *  1--绑卡
     *  2--开卡
     */
    private Integer type;

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getLevelCode() {
        return levelCode;
    }

    public void setLevelCode(String levelCode) {
        this.levelCode = levelCode;
    }

    public String getOfflineCardNo() {
        return offlineCardNo;
    }

    public void setOfflineCardNo(String offlineCardNo) {
        this.offlineCardNo = offlineCardNo;
    }

    public Integer getCountIntegeral() {
        return countIntegeral;
    }

    public void setCountIntegeral(Integer countIntegeral) {
        this.countIntegeral = countIntegeral;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Integer getGender() {
        return gender;
    }

    public void setGender(Integer gender) {
        this.gender = gender;
    }

    public String getBirthday() {
        return birthday;
    }

    public void setBirthday(String birthday) {
        this.birthday = birthday;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getCounty() {
        return county;
    }

    public void setCounty(String county) {
        this.county = county;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getOpenStoreCode() {
        return openStoreCode;
    }

    public void setOpenStoreCode(String openStoreCode) {
        this.openStoreCode = openStoreCode;
    }

    public String getOpenGuideCode() {
        return openGuideCode;
    }

    public void setOpenGuideCode(String openGuideCode) {
        this.openGuideCode = openGuideCode;
    }

    public String getEffectiveTime() {
        return effectiveTime;
    }

    public void setEffectiveTime(String effectiveTime) {
        this.effectiveTime = effectiveTime;
    }

    public Integer getFirstandingCheck() {
        return firstandingCheck;
    }

    public void setFirstandingCheck(Integer firstandingCheck) {
        this.firstandingCheck = firstandingCheck;
    }

    public String getErpId() {
        return erpId;
    }

    public void setErpId(String erpId) {
        this.erpId = erpId;
    }
}
